supabase

package module
v0.0.0-...-3de58ec Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 6, 2025 License: MIT Imports: 8 Imported by: 0

README

An isomorphic Go client for Supabase.

Features

  • Integration with Supabase.Realtime
    • Realtime listeners for database changes
  • Integration with Postgrest
    • Access your database using a REST API generated from your schema & database functions
  • Integration with Gotrue
    • User authentication, including OAuth, email/password, and native sign-in
  • Integration with Supabase Storage
    • Store files in S3 with additional managed metadata
  • Integration with Supabase Edge Functions
    • Run serverless functions on the edge

Quickstart

  1. To get started, create a new project in the Supabase Admin Panel.
  2. Grab your Supabase URL and Supabase Public Key from the Admin Panel (Settings -> API Keys).
  3. Initialize the client!

Reminder: supabase-go has some APIs that require the service_key rather than the public_key (for instance: the administration of users, bypassing database roles, etc.). If you are using the service_key be sure it is not exposed client side. Additionally, if you need to use both a service account and a public/user account, please do so using a separate client instance for each.

Documentation

Installation

Install the library to your go project:

  go get github.com/supabase-community/supabase-go

Quick start

  client, err := supabase.NewClient(API_URL, API_KEY, &supabase.ClientOptions{})
  if err != nil {
    fmt.Println("Failed to initalize the client: ", err)
  }

Client configuration

Basic Client
client, err := supabase.NewClient(url, key, nil)
Client with custom options
options := &supabase.ClientOptions{
    Headers: map[string]string{
        "X-Custom-Header": "custom-value",
    },
    Schema: "custom_schema", // defaults to "public"
}

client, err := supabase.NewClient(url, key, options)

Querying data

  // ...

  data, count, err := client.From("countries").Select("*", "exact", false).Execute()

For more see postgrest-go Query Builder documentation

Authentication

The client provides comprehensive authentication features through the integrated GoTrue client.

Email/Password Authentication
// Sign in with email and password
session, err := client.SignInWithEmailPassword("user@example.com", "password")
if err != nil {
    log.Fatal("Sign in failed:", err)
}

fmt.Printf("User ID: %s\n", session.User.ID)
fmt.Printf("Access Token: %s\n", session.AccessToken)

Phone/Password Authentication
// Sign in with phone and password
session, err := client.SignInWithPhonePassword("+1234567890", "password")
if err != nil {
    log.Fatal("Sign in failed:", err)
}

Token Management

Manual Token Refresh
// Refresh an expired token
newSession, err := client.RefreshToken(session.RefreshToken)
if err != nil {
    log.Fatal("Token refresh failed:", err)
}
Automatic Token Refresh
// Enable automatic token refresh in the background
client.EnableTokenAutoRefresh(session)

// The client will automatically:
// - Refresh tokens before they expire (at 75% of expiry time)
// - Retry failed refreshes with exponential backoff
// - Update all service clients with new tokens

Documentation

Index

Constants

const (
	REST_URL      = "/rest/v1"
	STORAGE_URL   = "/storage/v1"
	AUTH_URL      = "/auth/v1"
	FUNCTIONS_URL = "/functions/v1"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	Storage *storage_go.Client
	// Auth is an interface. We don't need a pointer to an interface.
	Auth      auth.Client
	Functions *functions.Client
	// contains filtered or unexported fields
}

func NewClient

func NewClient(url, key string, options *ClientOptions) (*Client, error)

NewClient creates a new Supabase client. url is the Supabase URL. key is the Supabase API key. options is the Supabase client options.

func (*Client) EnableTokenAutoRefresh

func (c *Client) EnableTokenAutoRefresh(session types.Session)

func (*Client) From

func (c *Client) From(table string) *postgrest.QueryBuilder

Wrap postgrest From method From returns a QueryBuilder for the specified table.

func (*Client) RefreshToken

func (c *Client) RefreshToken(refreshToken string) (types.Session, error)

func (*Client) Rpc

func (c *Client) Rpc(name, count string, rpcBody interface{}) string

Wrap postgrest Rpc method Rpc returns a string for the specified function.

func (*Client) SignInWithEmailPassword

func (c *Client) SignInWithEmailPassword(email, password string) (types.Session, error)

func (*Client) SignInWithPhonePassword

func (c *Client) SignInWithPhonePassword(phone, password string) (types.Session, error)

func (*Client) UpdateAuthSession

func (c *Client) UpdateAuthSession(session types.Session)

type ClientOptions

type ClientOptions struct {
	Headers map[string]string
	Schema  string
}

Directories

Path Synopsis

Jump to